@@ -258,12 +258,12 @@ impl ArgParser {
             println!("{}", input.help);
         };
 
-        if flags.is_empty() {
+        if !flags.is_empty() {
             println!("Flags:");
             flags.iter().for_each(|f| print(f));
         }
 
-        if options.is_empty() {
+        if !options.is_empty() {
             println!("Options:");
             options.iter().for_each(|o| print(o));
         }
